(function () {

    function truncateContent(content, numWords, endText, button) {
        let wordsArray = content.trim().split(/\s+/);
        if (wordsArray.length <= numWords) {
            if (button.disable == 'true') button.selector.style.display = 'none';
            return content;
        } else {
            let truncatedContent = '';
            let numTags = 0;
            let i = 0;
            while (i < wordsArray.length && i < numWords) {
                if (wordsArray[i].indexOf('<') === 0) {
                    numTags++;
                }
                if (wordsArray[i].indexOf('>') === wordsArray[i].length - 1) {
                    numTags--;
                }
                truncatedContent += wordsArray[i] + ' ';
                i++;
            }
            if (numTags > 0) {
                truncatedContent += '</' + wordsArray[i - 1].substr(wordsArray[i - 1].indexOf('<') + 1) + '>';
            }

            // remove trailing whitespace before appending ellipsis
            truncatedContent = truncatedContent.trimEnd();

            // add ellipsis
            if (endText) truncatedContent += endText;


            return truncatedContent;
        }
    }

    window.deOriginalContent = {};


    const deReadMoreContainer = document.querySelectorAll('.de-read-more');

    deReadMoreContainer.forEach(el => {


        const btn = el.querySelector('.de-read-more button');
        const content = el.querySelector('.de-read-more-content');
        const numWordsToShow = Number(el.getAttribute('data-word-count'));
        let customEndText = el.getAttribute('data-end-text');
        const dataType = el.getAttribute('data-type');
        const disableBtn = el.getAttribute('exclude-button');

        const id = el.classList[0].split('-').pop();
        const selector =  btn.getAttribute('data-selector') + ' .de-read-more-content';

        let innerContent = content.innerHTML;

        deOriginalContent[id] = {
            selector: selector,
            contentInner: innerContent ? innerContent : 'No Content Found',
            state: true,
            words: numWordsToShow ? numWordsToShow : false, 
            endText: customEndText ? customEndText : false, 
            dataType: el.getAttribute('data-type'), 
            closeName : btn.getAttribute('data-close-name'),
            openName : btn.getAttribute('data-open-name')
        };
        

        if (!customEndText) customEndText = false;

        if (dataType == 'text') {
            let truncatedContent = truncateContent(
                deOriginalContent[id].contentInner,
                numWordsToShow,
                customEndText,
                { selector: btn, disable: disableBtn }
            );
            content.innerHTML = truncatedContent;
        };
        
    });

    document.addEventListener('click', function(event) {
        const obj = event.target;
        if (!obj.closest('.de-read-more-button')) return;
        event.stopPropagation();

        const id = obj.parentNode.classList[0].split('-').pop();
        let content = document.querySelector(deOriginalContent[id].selector)

        // set state to true if closed, and false to open
        if (deOriginalContent[id].state == true) {
            deOriginalContent[id].state = false;
        } else {
            deOriginalContent[id].state = true;
        }

        let dataType = deOriginalContent[id].dataType

        // when it's open
        if (deOriginalContent[id].state == false) {
            // show all content when "Read Less" button is clicked
            if (dataType == 'text') content.innerHTML = deOriginalContent[id].contentInner; // set back to original content
            obj.innerHTML = deOriginalContent[id].closeName;
            content.classList.add('active');
        //when it's closed
        } else {
            // truncate content when "Read More" button is clicked
            if (dataType == 'text') content.innerHTML = truncateContent(
                deOriginalContent[id].contentInner,
                deOriginalContent[id].words,
                deOriginalContent[id].endText,
                { disable: false }
            );
            obj.innerHTML = deOriginalContent[id].openName;
            content.classList.remove('active');
        }
        
    });

    window.truncateContent = truncateContent;

})();