<?php
/**
 * TODO: Possibility to upload custom flags
 * https://polylang.pro/doc/can-i-use-my-own-flags-for-the-language-switcher/
 */

$language_plugin = $propertiesData['content']['content']['language_plugin'] ?? false;
if ($language_plugin === 'wpml' || $language_plugin === 'polylang') {
    
    // Show flags
    $showflags = $propertiesData['content']['content']['show_flags'] ?? false;

    // Custom flags
    $custom_flags = $propertiesData['content']['content']['custom_flags'] ?? false;
    $flags_array = [];
    // Check if custom flags has at least one element
    if (is_array($custom_flags) && count($custom_flags) > 0) {
        
        // Loop through each custom flag
        foreach ($custom_flags as $key => $flag) {
            // echo $flag['language'];
            // Check if flag has at least one element
            if (is_array($flag) && count($flag) > 0) {
                $flags_array[$flag['language']] = $flag['flag_image']['sizes']['thumbnail']['url'];
            }
        }
    }

    $flags_array_json = json_encode($flags_array);


    // Show name
    $showname = $propertiesData['content']['content']['show_name'] ?? false;

    // Language name (native or translated)
    $language_name = $propertiesData['content']['content']['language_name'] ?? false;
    
    // Hide current language from the list
    $hidecurrent = $propertiesData['content']['content']['hide_current'] ?? false;
    
    // Display name as (Name or code)
    $nameas = $propertiesData['content']['content']['display_name_as'] ?? '';

    // Display dropdown
    $dropdown_display = $propertiesData['content']['content']['dropdown_display'] ?? false;
    
    

    // Cast variables explicitly for better type safety. This ensures that the expected data types are always used
    $showname = (bool) $showname;
    $showflags = (bool) $showflags;
    $hidecurrent = (bool) $hidecurrent;
    $nameas = (string) $nameas;
    $dropdown_display = (int) $dropdown_display;
    $language_name = (string) $language_name;
    

    if($showname == 0 && $dropdown_display == 1) {
        $showname = 1;
    } 

    if ($language_plugin === 'wpml') {
        // Definiuj niestandardowe argumenty dla przełącznika języka
        $args = array(
            'flags' => $showflags,
            'link_current' => !$hidecurrent,
        );

        if ($showname) {
            $args[$language_name === 'native' ? 'native' : 'translated'] = 1;
        }

        $twig_template_path = dirname(__FILE__) . "/switcher_template.twig";


        $twig_template_string = file_get_contents($twig_template_path);
        
        // Add variables on the top of the template
        $twig_template_string = "
            {% set dropdown_display = $dropdown_display %}
            {% set name_as = '$nameas' %}
            {% set language_name_version = '$language_name' %}
            {% set show_flags = '$showflags' %}
            {% set show_name = '$showname' %}
            {% set custom_flags = $flags_array_json %}
        ". $twig_template_string;

        do_action('wpml_language_switcher', $args, $twig_template_string);
    } else if ($language_plugin === 'polylang') {
        
        $name_version = $propertiesData['content']['content']['name_version'] ?? false;
        ?>
            <ul class="polylang-switcher-list">
                <?php
                // Raw translations
                $raw_translations= pll_the_languages([
                    'raw' => 1,
                    'show_names' => $showname,
                    'show_flags' => $showflags,
                    'hide_current' => $hidecurrent,
                    'display_names_as' => $nameas,
                    'dropdown' => $dropdown_display

                ]);
                // Import the php template
                $template_path = dirname(__FILE__) . "/templates/polylang_template.php";
                include $template_path;
                ?>
            </ul>
        <?php
    }
} else {
    echo "Element supports WPML and Polylang plugins. Please install, activate and choose one of them.";
}
?>